@@ -23,12 +23,14 @@
   :use-module (srfi srfi-39)
   :autoload   (system documentation c-snarf) (run-cpp-and-extract-snarfing)
 
-  :export (schemify-name scheme-procedure-texi-line
-           procedure-gdf-string procedure-texi-documentation
+  :export (schemify-name
+           scheme-procedure-texi-line
+           procedure-gdf-string
+           procedure-texi-documentation
            output-procedure-texi-documentation-from-c-file
            *document-c-functions?*))
 
-;;; Author:  Ludovic Courts
+;;; Author:  Ludovic Courtès
 ;;;
 ;;; Commentary:
 ;;;
@@ -126,32 +128,32 @@ function."
          (file-name     (car location))
          (line          (cadr location))
          (documentation (assq-ref proc-doc 'documentation)))
-  (string-append (string #\newline)
-		 (format #f "@c snarfed from ~a:~a~%"
-			 file-name line)
+    (string-append (string #\newline)
+                   (format #f "@c snarfed from ~a:~a~%"
+                           file-name line)
 
-                 ;; document the Scheme procedure
-                 (scheme-procedure-texi-line proc-name
-                                             (map schemify-name args)
-                                             required-args optional-args
-                                             rest-arg?)
-                 (string #\newline)
+                   ;; document the Scheme procedure
+                   (scheme-procedure-texi-line proc-name
+                                               (map schemify-name args)
+                                               required-args optional-args
+                                               rest-arg?)
+                   (string #\newline)
 
-                 (if (*document-c-functions?*)
-                     (string-append
-                      ;; document the C function
-                      "@deffnx {C Function} " c-name " ("
-                      (if (null? args)
-                          "void"
-                          (string-join (map (lambda (arg)
-                                              (string-append "SCM " arg))
-                                            args)
-                                       ", "))
-                      ")" (string #\newline))
-                     "")
+                   (if (*document-c-functions?*)
+                       (string-append
+                        ;; document the C function
+                        "@deffnx {C Function} " c-name " ("
+                        (if (null? args)
+                            "void"
+                            (string-join (map (lambda (arg)
+                                                (string-append "SCM " arg))
+                                              args)
+                                         ", "))
+                        ")" (string #\newline))
+                       "")
 
-		 documentation (string #\newline)
-                 "@end deffn" (string #\newline))))
+                   documentation (string #\newline)
+                   "@end deffn" (string #\newline))))
 
 
 ;;;
@@ -170,7 +172,7 @@ function."
 
 ;;; Local Variables:
 ;;; mode: scheme
-;;; coding: latin-1
+;;; coding: utf-8
 ;;; End:
 
 ;;; arch-tag: 20ca493a-6f1a-4d7f-9d24-ccce0d32df49
